@@ -15,13 +15,13 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
-Foobar is distributed in the hope that it will be useful,
+MULTIPAGETIFF is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Foobar.  If not, see <https://www.gnu.org/licenses/>.
+along with MULTIPAGETIFF.  If not, see <https://www.gnu.org/licenses/>.
 
 """
 
@@ -29,3 +29,8 @@ from .main import Stack
 from .stacktools import *
 from .plot import *
 from .io import *
+from .config import config
+
+DEPTH_AXIS = 0
+VERTICAL_AXIS = 1
+HORIZONTAL_AXIS = 2
