@@ -1,3 +1,30 @@
+"""
+
+MULTIPAGETIFF
+
+tools for multipage tiff images manipulation
+
+author: Marco Pascucci
+copyright: 2018
+
+
+This file is part of MULTIPAGETIFF.
+
+MULTIPAGETIFF is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+MULTIPAGETIFF is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with MULTIPAGETIFF.  If not, see <https://www.gnu.org/licenses/>.
+
+"""
+
 from . import main as _stack
 from PIL import Image as _Image
 import numpy as _np
