@@ -1,7 +1,36 @@
+"""
+
+MULTIPAGETIFF
+
+tools for multipage tiff images manipulation
+
+author: Marco Pascucci
+copyright: 2018
+
+
+This file is part of MULTIPAGETIFF.
+
+MULTIPAGETIFF is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+MULTIPAGETIFF is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with MULTIPAGETIFF.  If not, see <https://www.gnu.org/licenses/>.
+
+"""
+
+import matplotlib.gridspec as _gridspec
 from .config import config as _config
 from matplotlib import pyplot as _plt
 from matplotlib import colorbar, colors
 import numpy as _np
+from .stacktools import get_orthogonal_slices as _get_orthogonal_slices
 
 
 def plot_selection(stack, page=None, plot_axis=None, **kwargs):
@@ -41,7 +70,7 @@ def set_cmap(cmap):
     _config.cmap = cmap
 
 
-def color_code(stack, threshold=0):
+def color_code(stack, threshold=0, axis=0):
     """
     Color code the pages of a multipage grayscale tiff image
     :param stack:
@@ -49,7 +78,15 @@ def color_code(stack, threshold=0):
     :return: a rgb multipage image (numpy array)
     """
     cmap = get_cmap()
-    selection = stack.pages
+    selection = stack.pages.copy()
+    # selection = selection.swapaxes(axis, 0)
+    if axis != 0:
+        selection = _np.rot90(selection, axes=(0, axis))
+    if axis == 2:
+        selection = _np.rot90(selection, axes=(2, 1))
+
+    s = selection.shape[0]
+
     rgb = _np.zeros((*selection.shape, 3))
     for i, img in enumerate(selection):
         img_min = img.min()
@@ -58,7 +95,7 @@ def color_code(stack, threshold=0):
         if (img_c != 0):
             img = (img-img_min)/img_c
         img[img < threshold] = 0
-        j = i/(stack.selection_length-1)
+        j = i/s
         rgb[i, :, :, 0] = img*cmap(j)[0]
         rgb[i, :, :, 1] = img*cmap(j)[1]
         rgb[i, :, :, 2] = img*cmap(j)[2]
@@ -66,44 +103,74 @@ def color_code(stack, threshold=0):
     return rgb
 
 
-def flatten(stack, threshold=0):
+def flatten_grayscale(stack, axis=0):
+    """Return the 2D max projection of the intensity along the specified axis.
+    depth = 0
+    vertical = 1
+    horizontal = 2
     """
-    generate the max projection of a stack.
+    return stack[:].max(axis=axis)
+
+
+def flatten(stack, threshold=0, axis=0):
+    """
+    Return the color-coded max projection of the stack values along the specified axis
+    (depth = 0, vertical = 1, horizontal = 2).
+
     The color map is defied in the cmap setting variable.
     The color map limits are defined by the stack start_page, keypage and end_page property.
-    :param stack:
+    :param stack: a Stack
     :param threshold: [0,1] intensity values below the threshold are set to zero
     :return: a numpy array
     """
-    imgs = stack.pages
+    imgs = stack.pages.copy()
+    # imgs = imgs.swapaxes(axis, 0)
+    if axis != 0:
+        imgs = _np.rot90(imgs, axes=(0, axis))
+    if axis == 2:
+        imgs = _np.rot90(imgs, axes=(2, 1))
     idx = _np.argmax(imgs, axis=0)
-    out = _np.zeros((*imgs.shape[1:], 3))
-    rgb = color_code(stack, threshold=threshold)
+    # the output rgb image
+    rgb = color_code(stack, threshold=threshold, axis=axis)
+    out = _np.zeros((*rgb.shape[1:3], 3))
+
     for i in range(out.shape[0]):
         for j in range(out.shape[1]):
             out[i, j, :] = rgb[idx[i, j], i, j]
     return out
 
 
-def plot_flatten(stack, threshold=0):
-    """
-    Plot the max projection and its color bar.
+def plot_flatten(stack, threshold=0, axis=0):
+    """Plot the max projection and its color bar.
+
+    The projection is done along the specified axis.
     The color map is defied in the cmap setting variable.
     The color map limits are defined by the stack start_page, keypage and end_page property.
     The labels are taken from the stack properties.
 
     :param stack:
-    :param threshold: [0,1] intensity values below the threshold are set to zero
+    :param threshold:
     :return: None
+
+    Args:
+        stack (Stack): a Stack
+        threshold (int, optional): [0,1] intensity values below the threshold are set to zero. Defaults to 0.
+        axis (int, optional): The axis of the projection (depth = 0, vertical = 1, horizontal = 2). Defaults to 0.
     """
+
     n = 10
     ax1 = _plt.subplot2grid((n, n), (0, 0), colspan=n-1, rowspan=n)
     ax2 = _plt.subplot2grid((n, n), (0, n-1), colspan=1, rowspan=n)
 
-    ax1.imshow(flatten(stack, threshold=threshold))
+    ax1.imshow(flatten(stack, threshold=threshold, axis=axis))
     ax1.set_title(stack.title)
-    norm = colors.Normalize(
-        vmin=stack.range_in_units[0], vmax=stack.range_in_units[1])
+    if axis == 0:
+        norm = colors.Normalize(
+            vmin=stack.range_in_units[0], vmax=stack.range_in_units[1])
+    else:
+        s = stack.pages.shape[axis]/2
+        norm = colors.Normalize(
+            vmin=-s*stack.dx, vmax=s*stack.dx,)
     cb1 = colorbar.ColorbarBase(ax2, cmap=get_cmap(),
                                 norm=norm,
                                 orientation='vertical')
@@ -154,7 +221,7 @@ def plot_pages(stack, pages=None, colorcoded=False, **kwargs):
     _plt.tight_layout()
 
 
-def get_xz(stack, y, x=None, length=None, interpolation=1):
+def get_xz_color_coded(stack, y, x=None, length=None, interpolation=1):
     """
     Get a slice of the stack on the XZ plane
     :param stack:
@@ -175,7 +242,6 @@ def get_xz(stack, y, x=None, length=None, interpolation=1):
 
     start = max(0, x-length//2)
     end = min(x+length//2, stack[0].shape[1])
-
     length = end-start
 
     xz = _np.zeros((len(stack)*interpolation, length, 3))
@@ -184,3 +250,58 @@ def get_xz(stack, y, x=None, length=None, interpolation=1):
             xz[j, :] = img[y, start:end]
 
     return xz
+
+
+def orthogonal_views(stack, v=None, h=None, z=None, **kwargs):
+    """
+    Plot orthogonal planes intersecting at the specified point.
+
+    The point is specified by the following coordinates:
+    v = vertical axis of the stack page (third dimension of pages array)
+    h = horizontal axis of the stack page (second dimension of pages array)
+    z = depth of the stack, page number (first dimension of pages array)
+    **kwargs are forwarded to the pyplot.imshow function
+
+    if a coordinate is missing, the center of that dimension is used.
+
+    """
+
+    fig = _plt.gcf()
+    gs1 = _gridspec.GridSpec(2, 2)
+
+    point = _np.array([z, v, h])
+
+    # the default point is in the middle of the stack
+    default_point = (_np.array(stack[:].shape)//2).astype(int)
+    # set default for unspecified coordinates
+    for i in range(len(point)):
+        if point[i] is None:
+            point[i] = default_point[i]
+
+    orto = _get_orthogonal_slices(stack, *point)
+
+    ax = fig.add_subplot(gs1[0])
+    av = 'v'
+    ah = 'h'
+    ax.imshow(orto[f'{av}{ah}'], **kwargs)
+    ax.scatter(h, v, facecolors='none', edgecolors='red')
+    ax.set_ylabel(av)
+    ax.set_xlabel(ah)
+
+    ax = fig.add_subplot(gs1[1])
+    av = 'z'
+    ah = 'v'
+    ax.imshow(orto[f'{av}{ah}'], **kwargs)
+    ax.scatter(v, z, facecolors='none', edgecolors='red')
+    ax.set_ylabel(av)
+    ax.set_xlabel(ah)
+
+    ax = fig.add_subplot(gs1[2])
+    av = 'z'
+    ah = 'h'
+    ax.imshow(orto[f'{av}{ah}'], **kwargs)
+    ax.scatter(h, z, facecolors='none', edgecolors='red')
+    ax.set_ylabel(av)
+    ax.set_xlabel(ah)
+
+    _plt.tight_layout()
